## Méthode Reinert de classification
##
## Données issues du "Grand débat".
## Source : https://www.kaggle.com/jlesuffleur/granddebat
##
## Table DEMOCRATIE_ET_CITOYENNETE.csv dont on a conservé
## que deux colonnes et tiré un échantillon de 3000 lignes :
## - participation_elections : "Que pensez-vous de la
##   participation des citoyens aux élections et comment
##   les inciter à y participer davantage ?"


## Chargement des extensions
library(tidyverse)
library(quanteda)
library(rainette)

## Import des données
d <- read_csv("grand_debat.csv")
View(d)

## Création du corpus
corp <- corpus(d, text_field = "participation_elections")
corp


## Prétraitement du corpus -----------------------------

# Tokenization
tok <- tokens(
    corp,
    remove_punct = TRUE,
    remove_numbers = TRUE
)
tok <- tokens_tolower(tok)
tok <- tokens_remove(tok, stopwords("fr"))
tok

# Création de la DTM
dtm <- dfm(tok)
dtm
# Filtrage des termes apparaissant au moins dans n documents
dtm <- dfm_trim(dtm, min_docfreq = 20)
## Aperçu de la DTM et de ses dimensions
dtm

## Classification
res <- rainette(dtm, k = 8)
res

## Exploration des résultats
rainette_explor(res, dtm, corp)

## Génération du graphique en 6 classes
rainette_plot(res, dtm, k = 6)

## Récupération du groupe de chaque document en 6 classes
corp$groupe <- cutree(res, k = 6)
table(corp$groupe)

## Nommage des groupes
corp$groupe[corp$groupe == 1] <- "divers"
corp$groupe[corp$groupe == 2] <- "bonne_chose"
corp$groupe[corp$groupe == 3] <- "confiance"
corp$groupe[corp$groupe == 4] <- "éducation"
corp$groupe[corp$groupe == 5] <- "blancs"
corp$groupe[corp$groupe == 6] <- "obligatoire"
table(corp$groupe)

## Récupération des documents d'un groupe
corpus_education <- corpus_subset(corp, groupe == "éducation")
